summaryrefslogtreecommitdiff
path: root/examples/main-tab/simple.cpp
Side-by-side diff
Diffstat (limited to 'examples/main-tab/simple.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--examples/main-tab/simple.cpp11
1 files changed, 5 insertions, 6 deletions
diff --git a/examples/main-tab/simple.cpp b/examples/main-tab/simple.cpp
index 7edb557..1e2d028 100644
--- a/examples/main-tab/simple.cpp
+++ b/examples/main-tab/simple.cpp
@@ -8,3 +8,2 @@
#include <qpe/qpeapplication.h> // the QPEApplication
-#include <qpe/resource.h>
#include <qpe/sound.h>
@@ -12,2 +11,3 @@
#include <opie2/oapplicationfactory.h> // a template + macro to save the main method and allow quick launching
+#include <opie2/oresource.h>
#include <opie2/otabwidget.h>
@@ -89,3 +89,3 @@ void MainWindow::initUI() {
- QAction *a = new QAction( tr("Quit"), Resource::loadIconSet("quit_icon"),
+ QAction *a = new QAction( tr("Quit"), Opie::Core::OResource::loadPixmap("quit_icon", Opie::Core::OResource::SmallIcon),
QString::null, 0, this, "quit_action" );
@@ -98,4 +98,3 @@ void MainWindow::initUI() {
- a = new QAction(tr("Fire"),
- Resource::loadIconSet("new"),
+ a = new QAction(tr("Fire"), Opie::Core::OResource::loadPixmap("new", Opie::Core::OResource::SmallIcon),
QString::null, 0, this, "fire_button");
@@ -175,3 +174,3 @@ Simple2::Simple2( QWidget* parent, const char* name, WFlags fl )
/*
* Resource will search hard for a Pixmap in $OPIEDIR/pics
* to find 'logo/opielogo' You need to pass the subdir
@@ -179,3 +178,3 @@ Simple2::Simple2( QWidget* parent, const char* name, WFlags fl )
*/
- lbl->setPixmap( Resource::loadPixmap("logo/opielogo") );
+ lbl->setPixmap( Opie::Core::OResource::loadPixmap("logo/opielogo", Opie::Core::OResource::SmallIcon) );
layout->addWidget( lbl );
@@ -175,3 +174,3 @@ Simple2::Simple2( QWidget* parent, const char* name, WFlags fl )
/*
- * Resource will search hard for a Pixmap in $OPIEDIR/pics
+ * OResource will search hard for a Pixmap in $OPIEDIR/pics
* to find 'logo/opielogo' You need to pass the subdir